@@ -26,6 +26,7 @@ setLocalTranslate('cl_install3', sys.modules[__name__])
 __ = getLazyLocalTranslate(_)
 
 from calculate.core.server.func import WsdlBase
+from calculate.lib.utils.partition import VolumesError
 from calculate.install.utils.cl_install import ClInstallAction
 from calculate.install.utils.cl_setup import (
     ClSetupLocaleAction, ClSetupVideoAction, ClSetupSystemAction,
@@ -56,7 +57,7 @@ class Wsdl(WsdlBase):
         'action': ClInstallAction,
         # объект переменных
         'datavars': "install",
-        'native_error': (VariableError, DistributiveError,
+        'native_error': (VariableError, DistributiveError, VolumesError,
                          DataVarsError, install.InstallError),
         # значения по умолчанию для переменных этого метода
         'setvars': {'cl_action!': 'system', 'cl_install_type': 'hdd',
@@ -75,7 +76,7 @@ class Wsdl(WsdlBase):
                                 expert=('cl_image_linux_shortname',
                                         'cl_image_arch_machine',
                                         'cl_image_new_only')),
-            lambda group: group(_("Allocate drive space"),
+            lambda group: group(_("Installation type"),
                                 normal=('cl_autopartition_set',),
                                 hide=('cl_autopartition_set',
                                       'cl_autopartition_root_size',
@@ -87,17 +88,18 @@ class Wsdl(WsdlBase):
                                         'cl_autopartition_swap_size',
                                         'cl_autopartition_device'),
                                 expert_label=_(
-                                    "Click to set up autopartition options")),
-            lambda group: group(_("Mount points"),
+                                    "Click to select partitions to be created")
+                                ),
+            lambda group: group(_("Layout"),
                                 normal=('os_location_data',),
                                 hide=('os_location_data', 'os_install_mbr',
-                                      'os_install_uefi_set'),
+                                      'os_install_uefi'),
                                 brief_force=('os_location_brief_data',
                                              'os_install_bootloader'),
-                                brief=('os_install_uefi_brief_set',),
+                                brief=('os_install_uefi',),
                                 expert=('cl_uuid_set',
                                         'os_install_mbr',
-                                        'os_install_uefi_set',
+                                        'os_install_uefi',
                                         'os_install_kernel_scheduler')),
             lambda group: group(_("Network settings"),
                                 normal=(
@@ -148,7 +150,7 @@ class Wsdl(WsdlBase):
             'logic': {'Install': install.Install},
             'action': ClInstallAction,
             'datavars': "install",
-            'native_error': (VariableError, DistributiveError,
+            'native_error': (VariableError, DistributiveError, VolumesError,
                              DataVarsError, install.InstallError),
             'setvars': {'cl_action!': 'system', 'cl_install_type': 'flash',
                         'cl_protect_use_set!': 'off',
@@ -211,7 +213,7 @@ class Wsdl(WsdlBase):
                 lambda group: group(_("Boot"),
                                     normal=(
                                         'os_install_mbr',
-                                        'os_install_uefi_set',
+                                        'os_install_uefi',
                                         'os_install_kernel_scheduler',
                                         'os_install_grub_terminal',
                                         'cl_grub_pwd',
